#[non_exhaustive]pub struct VectorCapacity {
pub vector_search_request_bytes: Option<f64>,
pub vector_write_request_bytes: Option<f64>,
}Expand description
The consumed capacity for vector index operations, including vector search request bytes and vector write request bytes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.vector_search_request_bytes: Option<f64>The number of vector search request bytes consumed by a SearchVectors operation.
vector_write_request_bytes: Option<f64>The number of vector write request bytes consumed when writing to a vector index. Reported for write operations that modify attributes indexed by a vector index.
Implementations
Sourceimpl VectorCapacity
impl VectorCapacity
Sourcepub fn vector_search_request_bytes(&self) -> Option<f64>
pub fn vector_search_request_bytes(&self) -> Option<f64>
The number of vector search request bytes consumed by a SearchVectors operation.
Sourcepub fn vector_write_request_bytes(&self) -> Option<f64>
pub fn vector_write_request_bytes(&self) -> Option<f64>
The number of vector write request bytes consumed when writing to a vector index. Reported for write operations that modify attributes indexed by a vector index.
Sourceimpl VectorCapacity
impl VectorCapacity
Sourcepub fn builder() -> VectorCapacityBuilder
pub fn builder() -> VectorCapacityBuilder
Creates a new builder-style object to manufacture VectorCapacity.