#[non_exhaustive]pub struct VectorIndexDescription {
pub index_name: Option<String>,
pub search_schema: Option<Vec<SearchSchemaElement>>,
pub projection: Option<Projection>,
pub vector_attribute: Option<VectorAttributeDefinition>,
pub dimensions: Option<i64>,
pub distance_function: Option<VectorDistanceFunction>,
pub index_status: Option<IndexStatus>,
pub backfilling: Option<bool>,
pub index_size_bytes: Option<i64>,
pub item_count: Option<i64>,
pub index_arn: Option<String>,
}Expand description
Contains the current state and configuration of a vector index, including its status, size, item count, and the settings specified when the index was created.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.index_name: Option<String>The name of the vector index.
search_schema: Option<Vec<SearchSchemaElement>>The search schema that defines partition key and inline filter attributes for the vector index.
projection: Option<Projection>Specifies attributes that are copied (projected) from the table into the vector index.
vector_attribute: Option<VectorAttributeDefinition>The vector attribute configuration for the index.
dimensions: Option<i64>The number of dimensions in each vector.
distance_function: Option<VectorDistanceFunction>The distance function used to calculate similarity between vectors.
index_status: Option<IndexStatus>The current state of the vector index:
-
CREATING- The index is being created. -
ACTIVE- The index is ready for use. -
DELETING- The index is being deleted.
backfilling: Option<bool>Specifies whether the index is currently backfilling. During backfill, SearchVectors operations might return incomplete results.
index_size_bytes: Option<i64>The total size of the vector index, in bytes. Amazon DynamoDB updates this value approximately every six hours. Recent changes might not be reflected in this value.
item_count: Option<i64>The number of items indexed in the vector index. Amazon DynamoDB updates this value approximately every six hours. Recent changes might not be reflected in this value.
index_arn: Option<String>The Amazon Resource Name (ARN) that uniquely identifies the vector index.
Implementations
Sourceimpl VectorIndexDescription
impl VectorIndexDescription
Sourcepub fn index_name(&self) -> Option<&str>
pub fn index_name(&self) -> Option<&str>
The name of the vector index.
Sourcepub fn search_schema(&self) -> &[SearchSchemaElement]
pub fn search_schema(&self) -> &[SearchSchemaElement]
The search schema that defines partition key and inline filter attributes for the vector index.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .search_schema.is_none().
Sourcepub fn projection(&self) -> Option<&Projection>
pub fn projection(&self) -> Option<&Projection>
Specifies attributes that are copied (projected) from the table into the vector index.
Sourcepub fn vector_attribute(&self) -> Option<&VectorAttributeDefinition>
pub fn vector_attribute(&self) -> Option<&VectorAttributeDefinition>
The vector attribute configuration for the index.
Sourcepub fn dimensions(&self) -> Option<i64>
pub fn dimensions(&self) -> Option<i64>
The number of dimensions in each vector.
Sourcepub fn distance_function(&self) -> Option<&VectorDistanceFunction>
pub fn distance_function(&self) -> Option<&VectorDistanceFunction>
The distance function used to calculate similarity between vectors.
Sourcepub fn index_status(&self) -> Option<&IndexStatus>
pub fn index_status(&self) -> Option<&IndexStatus>
The current state of the vector index:
-
CREATING- The index is being created. -
ACTIVE- The index is ready for use. -
DELETING- The index is being deleted.
Sourcepub fn backfilling(&self) -> Option<bool>
pub fn backfilling(&self) -> Option<bool>
Specifies whether the index is currently backfilling. During backfill, SearchVectors operations might return incomplete results.
Sourcepub fn index_size_bytes(&self) -> Option<i64>
pub fn index_size_bytes(&self) -> Option<i64>
The total size of the vector index, in bytes. Amazon DynamoDB updates this value approximately every six hours. Recent changes might not be reflected in this value.
Sourcepub fn item_count(&self) -> Option<i64>
pub fn item_count(&self) -> Option<i64>
The number of items indexed in the vector index. Amazon DynamoDB updates this value approximately every six hours. Recent changes might not be reflected in this value.
Sourceimpl VectorIndexDescription
impl VectorIndexDescription
Sourcepub fn builder() -> VectorIndexDescriptionBuilder
pub fn builder() -> VectorIndexDescriptionBuilder
Creates a new builder-style object to manufacture VectorIndexDescription.